#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['iuliia', 'iuliia.schemas']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['iuliia = iuliia.__main__:main']}

setup(name='iuliia',
      version='0.9.0',
      description='Transliterate Cyrillic → Latin in every possible way',
      author='Anton Zhiyanov',
      author_email='m@antonz.ru',
      url='https://github.com/nalgeon/iuliia-py',
      packages=packages,
      package_data=package_data,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
